@@ -26,9 +26,6 @@ class BotData(mongoengine.Document):
 
 from pymongo import monitoring
 
-logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-                    level=logging.INFO)
-
 logger = logging.getLogger(__name__)
 
 class CommandLogger(monitoring.CommandListener):
