@@ -1,38 +1,37 @@
 
 import re
 EMOJI_PATTERN = re.compile(
-    "["
-    "\U0001F1E0-\U0001F1FF"  # flags (iOS)
-    "\U0001F300-\U0001F5FF"  # symbols & pictographs
-    "\U0001F600-\U0001F64F"  # emoticons
-    "\U0001F680-\U0001F6FF"  # transport & map symbols
-    "\U0001F700-\U0001F77F"  # alchemical symbols
-    "\U0001F780-\U0001F7FF"  # Geometric Shapes Extended
-    "\U0001F800-\U0001F8FF"  # Supplemental Arrows-C
-    "\U0001F900-\U0001F9FF"  # Supplemental Symbols and Pictographs
-    "\U0001FA00-\U0001FA6F"  # Chess Symbols
-    "\U0001FA70-\U0001FAFF"  # Symbols and Pictographs Extended-A
-    "\U00002702-\U000027B0"  # Dingbats
-    "\U000024C2-\U0001F251"
-    "]+"
+    r"["
+    r"\U0001F1E0-\U0001F1FF"  # flags (iOS)
+    r"\U0001F300-\U0001F5FF"  # symbols & pictographs
+    r"\U0001F600-\U0001F64F"  # emoticons
+    r"\U0001F680-\U0001F6FF"  # transport & map symbols
+    r"\U0001F700-\U0001F77F"  # alchemical symbols
+    r"\U0001F780-\U0001F7FF"  # Geometric Shapes Extended
+    r"\U0001F800-\U0001F8FF"  # Supplemental Arrows-C
+    r"\U0001F900-\U0001F9FF"  # Supplemental Symbols and Pictographs
+    r"\U0001FA00-\U0001FA6F"  # Chess Symbols
+    r"\U0001FA70-\U0001FAFF"  # Symbols and Pictographs Extended-A
+    r"\U00002702-\U000027B0"  # Dingbats
+    r"\U000024C2-\U0001F251"
+    r"]+"
 )
 
+JAHRESZAHL_PATTERN = re.compile(r"(?P<jahreszahl>\d{1,4})")
+
+KOMMAZAHL_PATTERN = re.compile(r"(?P<vorkomma>\d+),? ?(?P<nachkomma>\d*)")
+
 ZURUECK_PATTERN = re.compile(
     "^("
     "zurueck|"
-    "zurück|"
-    "Zurueck|"
-    "Zurück|"
-    ")$"
+    "zurück"
+    ")$", re.IGNORECASE
 )
 
 WEITER_PATTERN = re.compile(
     "^("
     "gefunden|"
     "bescheid|"
-    "Weiter|"
-    "Bescheid|"
-    "Gefunden|"
     "weiter|"
     "next|"
     "nächster|"
@@ -45,7 +44,7 @@ WEITER_PATTERN = re.compile(
     "ueber springen|"
     "waiter|"
     "bin soweit|"
-    ")$"
+    ")$", re.IGNORECASE
 )
 
 WOHIN_PATTERN = re.compile(
@@ -67,7 +66,7 @@ WOHIN_PATTERN = re.compile(
     "hilfe|"
     "wie|"
     "Wie"
-    ")$"
+    ")$", re.IGNORECASE
 )
 
 JA_PATTERN = re.compile(
@@ -196,7 +195,7 @@ JA_PATTERN = re.compile(
     "bestimmt|"
     "in der Tat|"
     "positiv|"
-    ")$"
+    ")$", re.IGNORECASE
 )
 
 
@@ -234,5 +233,5 @@ NEIN_PATTERN = re.compile(
     "mitnichten|"
     "keineswegs|"
     "gar nicht|"
-    ")$"
+    ")$", re.IGNORECASE
 )
