@@ -10,9 +10,6 @@ import json
 config = ConfigParser() 
 config.read('config.ini')
 
-logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-                    level=logging.INFO)
-
 logger = logging.getLogger(__name__)
 
 
