@@ -28,7 +28,7 @@ class Action():
             
             wait_itteration = 0
             max_wait_itteration = 50
-            while unsend_messages[update.From] or wait_itteration >= max_wait_itteration:
+            while unsend_messages[update.From] and wait_itteration <= max_wait_itteration:
                 time.sleep(.1)
                 wait_itteration+=1
 
